@@ -67,6 +67,9 @@ def commits_by_short_gitsha1(repo_path, repo):
         history_reference = short_gitsha1(repo, commit.hash)
         commits[history_reference] = commit
 
+    if len(commits) == 0:
+        raise Exception('No commits found in "%s"' % repo_path)
+
     return commits
 
 
@@ -74,6 +77,8 @@ def commit_datetime_from_history_reference(history_reference, commits):
     first_matching_commit_history_reference_key = next(
         filter(lambda _: _.startswith(history_reference), commits.keys()), False
     )
+    if not first_matching_commit_history_reference_key:
+        raise Exception('No commit matching "%s" found' % history_reference)
     return commits[first_matching_commit_history_reference_key].author_date
 
 
@@ -105,6 +110,10 @@ def export_file_name_by_record_type(record_type, suffix=""):
     return (export_file_name, export_file_name_base)
 
 
+class InvalidPreviouslyEditedDfException(BaseException):
+    pass
+
+
 def possibly_edited_df_util(
     current_commit_df,
     record_type,
@@ -210,18 +219,25 @@ def possibly_edited_df_util(
         previous_possibly_edited_df = pd.read_excel(
             previous_possibly_edited_df_xlsx_path
         )
-        (
-            df_with_previous_edits_across_columns,
-            additional_columns_to_drop_after_propagation_of_previous_edits,
-        ) = merge_changes_from_previous_possibly_edited_df(
-            accumulating_df=df_with_previous_edits_across_columns,
-            previous_possibly_edited_df=previous_possibly_edited_df,
-            edit_file=edit_file,
-            record_type=record_type,
-            clerkai_input_folder_path=clerkai_input_folder_path,
-            current_history_reference=current_history_reference,
-            keep_unmerged_previous_edits=keep_unmerged_previous_edits,
-        )
+        try:
+            (
+                df_with_previous_edits_across_columns,
+                additional_columns_to_drop_after_propagation_of_previous_edits,
+            ) = merge_changes_from_previous_possibly_edited_df(
+                accumulating_df=df_with_previous_edits_across_columns,
+                previous_possibly_edited_df=previous_possibly_edited_df,
+                edit_file=edit_file,
+                record_type=record_type,
+                clerkai_input_folder_path=clerkai_input_folder_path,
+                current_history_reference=current_history_reference,
+                keep_unmerged_previous_edits=keep_unmerged_previous_edits,
+            )
+        except InvalidPreviouslyEditedDfException as e:
+            print(
+                "Warning: Ignoring invalid previous_possibly_edited_df (%s)" % e,
+                previous_possibly_edited_df,
+            )
+            continue
         columns_to_drop_after_propagation_of_previous_edits = [
             *columns_to_drop_after_propagation_of_previous_edits,
             *additional_columns_to_drop_after_propagation_of_previous_edits,
@@ -663,6 +679,20 @@ def merge_changes_from_previous_possibly_edited_df(
     else:
         raise ValueError("record_type '%s' not recognized" % record_type)
 
+    # sanity check
+    if file_name_column_name not in previous_possibly_edited_df.columns:
+        raise InvalidPreviouslyEditedDfException(
+            "Missing column: %s" % file_name_column_name
+        )
+    if file_path_column_name not in previous_possibly_edited_df.columns:
+        raise InvalidPreviouslyEditedDfException(
+            "Missing column: %s" % file_path_column_name
+        )
+    if additional_join_column not in previous_possibly_edited_df.columns:
+        raise InvalidPreviouslyEditedDfException(
+            "Missing column: %s" % additional_join_column
+        )
+
     # print("df.head(), edit_file, previous_possibly_edited_df.head()")
     # print(df.head(), edit_file, previous_possibly_edited_df.head())
 
